home | help
dvb-fe-tool(1)			  User Commands 		  dvb-fe-tool(1)

NAME
     dvb-fe-tool - DVBv5 tool for frontend settings inspect/change

SYNOPSIS
     dvb-fe-tool [OPTION]...

DESCRIPTION
     dvbv5-fe-tool  is	a command line tool for digital TV services that is com-
     pliant with version 5 of the DVB API,  and  backward  compatible  with  the
     older v3 DVB API.

     dvb-fe-tool  is a tool to inspect and change the tuning parameters directly
     at the Digital TV frontend. If called without any parameter, it  will  show
     the device capabilities.

OPTIONS
     The following options are valid:

     -3, --dvbv3
	    Use DVBv3 only

     -a, --adapter=ADAPTER
	    Digital TV adapter to use. Default: 0.

     -A, --acoustical
	    beeps if signal quality is good. Also enables femon mode. Please no-
	    tice that console beep should be enabled on your wm.

     -d, --set-delsys=PARAMS
	    Sets  delivery  system  to	the one specified at PARAMS. use help to
	    show all supported delivery systems.

     -f, --frontend=FRONTEND
	    Digital TV frontend to use. Default: 0.

     -g, --get
	    Gets frontend parameters.

     -m, --femon
	    Monitors the frontend locking status and  the  available  statistics
	    for a frontend that it is already being streaming via some other ap-
	    plication.	This opens the frontend on read-only mode.

     -v, --verbose
	    Enables debug messages.

     -?, --help
	    Outputs the usage help.

     --usage
	    Gives a short usage message.

     -V, --version
	    Prints program version.

EXIT STATUS
     On success, it returns 0.

EXAMPLES
   Showing device capabilities
     This is the default behavior. It will open the frontend and show what capa-
     bilities it supports and what's the version of the DVB API.

     $ dvb-fe-tool
     Device DRXK DVB-C DVB-T (/dev/dvb/adapter0/frontend0) capabilities:
	  CAN_FEC_1_2
	  CAN_FEC_2_3
	  CAN_FEC_3_4
	  CAN_FEC_5_6
	  CAN_FEC_7_8
	  CAN_FEC_AUTO
	  CAN_GUARD_INTERVAL_AUTO
	  CAN_HIERARCHY_AUTO
	  CAN_INVERSION_AUTO
	  CAN_MUTE_TS
	  CAN_QAM_16
	  CAN_QAM_32
	  CAN_QAM_64
	  CAN_QAM_128
	  CAN_QAM_256
	  CAN_RECOVER
	  CAN_TRANSMISSION_MODE_AUTO
     DVB API Version 5.10, Current v5 delivery system: DVBC/ANNEX_A
     Supported delivery systems:
	 [DVBC/ANNEX_A]
	  DVBC/ANNEX_C
	  DVBT

   Setting the delivery system
     Some  devices  (like the above example) supports multiple delivery systems.
     Older DVB applications might not be able to switch from one delivery system
     to another one, as this feature were added only on DVB API version 5.5.

     This feature allows one to use those legacy applications.

     $ dvb-fe-tool -d dvbc/annex_c
     Changing delivery system to: DVBC/ANNEX_C

   Getting the current frontend settings
     The tool can also be used to get the current settings.  In  this  case,  it
     will  open  the  frontend at read-only mode, allowing it to be called while
     some other digital TV application is running.

     $ dvb-fe-tool -g
     FREQUENCY = 573000000
     MODULATION = QAM/256
     INVERSION = AUTO
     SYMBOL_RATE = 5217000
     INNER_FEC = NONE
     DELIVERY_SYSTEM = DVBC/ANNEX_A

   Monitoring the frontend
     The dvb-fe-tool can also be used to monitor a DVB frontend statistics with-
     out touching on the device, using the --femon (or -m) parameter.  The typi-
     cal usage is to be able to read the statistics while some other DVB program
     or application is in use.

     On this mode, it will keep printing the frontend statistics on  every  sec-
     ond, until the program is aborted with CTRL-C:

     For example, while dvbv5-zap is tuning some channel, it will produce:

     $ dvb-fe-tool --femon
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.40dB UCB= 370 postBER= 28.0x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.80dB UCB= 370 postBER= 25.3x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.30dB UCB= 370 postBER= 25.7x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.30dB UCB= 370 postBER= 28.4x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.50dB UCB= 370 postBER= 26.5x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.50dB UCB= 370 postBER= 26.9x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.20dB UCB= 370 postBER= 28.6x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.70dB UCB= 370 postBER= 26.7x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.80dB UCB= 370 postBER= 23.3x10^-6 PER= 0
     Lock   (0x1f) Quality= Good Signal= 100.00% C/N= 36.50dB UCB= 370 postBER= 26.7x10^-6 PER= 0

     If  the  standard error device is the console, the messages will be colored
     according with the signal quality.

     The presented statistics types and unities will depend on the ones that the
     hardware you're using support. So, it may vary from hardware to hardware.

     On this mode, it also supports to output an audible signal if  the  quality
     is good, using the '-A' parameter.

     Please notice that, on modern Linux systems, the system audio should be en-
     abled  at	your window manager and the audio theme should be set to produce
     an audio when BELL (character) is sent to the terminal.

   NOTE:
     C/N on the above stats means Carrier to Noise ratio. This is the Signal  to
     Noise ratio measured at the pilot carrier or just the Signal to Noise ratio
     for modulation types where just one carrier is used, like DVB-C or DVB-S.

BUGS
     Report bugs to Linux Media Mailing List <linux-media@vger.kernel.org>

COPYRIGHT
     Copyright (c) 2011-2014 by Mauro Carvalho Chehab.

     License GPLv2: GNU GPL version 2 <http://gnu.org/licenses/gpl.html>.
     This  is  free software: you are free to change and redistribute it.  There
     is NO WARRANTY, to the extent permitted by law.

DVBv5 Utils 1.23.0		 Fri Oct 3 2014 		  dvb-fe-tool(1)

home | help